`ensembleMemberLabels` <-
function (x) 
UseMethod("ensembleMemberLabels")

